@@ -1,7 +1,7 @@
 var struct__EnchantBroker =
 [
     [ "_error", "struct__EnchantBroker.html#a88844610d8bba32f8ee527efdc987d9b", null ],
-    [ "dict_list", "struct__EnchantBroker.html#a39b2eb0d057b822a5478fc2fbaeb9aac", null ],
+    [ "dicts", "struct__EnchantBroker.html#accd6f11dd22ef7cf5060bc709649ff30", null ],
     [ "provider_list", "struct__EnchantBroker.html#a1e9e2151bb451d8b7b3e5c1fe6017ad3", null ],
     [ "provider_ordering", "struct__EnchantBroker.html#afb3003e5e7ba68c446d0a016e8a8f0f1", null ]
 ];
\ No newline at end of file
